@@ -9,7 +9,7 @@ class Account():
     def __init__(self):
         self.symbol = ''
         self.__settings()
-        self.free_balance = self.__capital
+        self.free_balance = self._capital
         self.user_portfolio = pd.DataFrame(columns=['Security', 'Amount','Value'])
         self.total_value = self.free_balance + self.user_portfolio['Value'].sum() + self._on_hold
         self.costs_fees = 0
@@ -25,10 +25,10 @@ class Account():
 
 
     def __settings(self):
-            self.__capital = 20000
-            self.__fees_perc = 0
-            self.__slippage = 0.0003
-            self.__leverage = 20
+            self._capital = 20000
+            self._fees_perc = 0
+            self._slippage = 0.0003
+            self._leverage = 20
             self._on_hold = 0
             self._on_hold_book = pd.DataFrame(columns=['Position ID','Amount','Value'])
             self._borrowed_money = 0
@@ -80,33 +80,33 @@ class Portfolio(Account):
         pID = ''.join(random.choices(string.ascii_letters+string.digits,k=7))
         if ptype =='Buy':
 
-            oprice = oprice *(1+self.__slippage)
-            bamount = amount * (self.__leverage-1)
+            oprice = oprice *(1+self._slippage)
+            bamount = amount * (self._leverage-1)
             tamount = bamount + amount
             newBorrowed = pd.Series(data=[pID, bamount*oprice],index=self._borrowed_book.columns)
             newBorrowed.name = ''.join(random.choices(string.ascii_letters+string.digits,k=7))
             self._borrowed_book = self._borrowed_book.append(newBorrowed)
             self._borrowed_money = self._borrowed_book['Value'].sum()
 
-            self.user_positions.loc[pID,:] = [sec, oprice, odate, '-','-',tamount,-tamount*oprice*self.__fees_perc, 0]
+            self.user_positions.loc[pID,:] = [sec, oprice, odate, '-','-',tamount,-tamount*oprice*self._fees_perc, 0]
         else:
             
-            oprice = oprice*(1-self.__slippage)
-            bamount = amount * (self.__leverage-1)
+            oprice = oprice*(1-self._slippage)
+            bamount = amount * (self._leverage-1)
             tamount = bamount + amount
 
             self._borrowed_book.loc[''.join(random.choices(string.ascii_letters+string.digits,k=7)),:] = [pID, bamount*oprice]
             self._borrowed_money = self._borrowed_book['Value'].sum()
 
-            self.user_positions.loc[pID,:] = [sec, oprice, odate, '-','-',-tamount,-tamount*oprice*self.__fees_perc, 0]
+            self.user_positions.loc[pID,:] = [sec, oprice, odate, '-','-',-tamount,-tamount*oprice*self._fees_perc, 0]
 
             ohID = ''.join(random.choices(string.ascii_letters+string.digits,k=7))
 
             self._on_hold_book.loc[ohID,:] = [pID, 2*tamount, 2*tamount*oprice]
             self._on_hold = self._on_hold_book['Value'].sum()
 
-        self.free_balance -= (tamount * oprice * self.__fees_perc + amount*oprice)
-        self.costs_fees += tamount * oprice * self.__fees_perc
+        self.free_balance -= (tamount * oprice * self._fees_perc + amount*oprice)
+        self.costs_fees += abs(tamount * oprice * self._fees_perc)
         if sec in self.user_portfolio['Security'].values:
 
             self._update_assets_amount(oprice)
@@ -145,8 +145,8 @@ class Portfolio(Account):
         self._borrowed_book = self._borrowed_book.drop(bmID,axis=0)
         self._borrowed_money =self._borrowed_book['Value'].sum()
         
-        self.free_balance -= abs(tamount * price * self.__fees_perc)
-        self.costs_fees += abs(tamount * price * self.__fees_perc)
+        self.free_balance -= abs(tamount * price * self._fees_perc)
+        self.costs_fees += abs(tamount * price * self._fees_perc)
         self._update_assets_amount(price)
 
 
@@ -155,11 +155,11 @@ class Portfolio(Account):
             oPrice = self.user_positions.loc[pID,'OPrice']
             pAmount = self.user_positions.loc[pID,'Amount']
             if pAmount >0:
-                self.user_positions.loc[pID,'PNL'] = -abs(pAmount*oPrice*self.__fees_perc) + (cprice - oPrice)*abs(pAmount)
-                self.user_positions.loc[pID,'Performance'] = self.user_positions.loc[pID,'PNL'] / abs(oPrice * pAmount) * self.__leverage *100
+                self.user_positions.loc[pID,'PNL'] = -abs(pAmount*oPrice*self._fees_perc) + (cprice - oPrice)*abs(pAmount)
+                self.user_positions.loc[pID,'Performance'] = self.user_positions.loc[pID,'PNL'] / abs(oPrice * pAmount) * self._leverage *100
             else:
-                self.user_positions.loc[pID,'PNL'] = -abs(pAmount*oPrice*self.__fees_perc) + (oPrice - cprice)*abs(pAmount)
-                self.user_positions.loc[pID,'Performance'] = self.user_positions.loc[pID,'PNL'] / abs(oPrice * pAmount)* self.__leverage * 100
+                self.user_positions.loc[pID,'PNL'] = -abs(pAmount*oPrice*self._fees_perc) + (oPrice - cprice)*abs(pAmount)
+                self.user_positions.loc[pID,'Performance'] = self.user_positions.loc[pID,'PNL'] / abs(oPrice * pAmount)* self._leverage * 100
 
 
     def _update_assets_amount(self, price):
@@ -219,7 +219,7 @@ class Broker(Trader):
         
 
     def __execute_opening_order(self, dtime, price, oID):
-        if abs(self.orders.loc[oID,'Amount'] * price) > self.free_balance or self._on_hold/self.__leverage > 1*self.total_value/2:
+        if abs(self.orders.loc[oID,'Amount'] * price) > self.free_balance or self._on_hold/self._leverage > 1*self.total_value/2:
             self.orders.loc[oID,'Status'] = 'NotExecutedIF'
         elif self.orders.loc[oID,'Amount'] == 0:
             self.orders.loc[oID,'Status'] = 'NotExecutedN'
@@ -259,10 +259,10 @@ class Engine(Broker):
         """Period can be 1m-59m, 1h-23h, 1d-29d, 1M-11M, Xy"""
         super().__init__()
         
-        self.__slippage = slippage
-        self.__leverage = leverage
-        self.__fees_perc = fees
-        self.__capital = capital
+        self._slippage = slippage
+        self._leverage = leverage
+        self._fees_perc = fees
+        self._capital = capital
         if ticker is not None:
             self.symbol = ticker
         else:
@@ -339,7 +339,7 @@ class Engine(Broker):
         
         for point, _ in zip(period,progressbar.progressbar(range(period_data.shape[0]))):
             dpoint = period_data[point]
-            pnl = pd.Series(data=[round((self.total_value/self.__capital-1)*100,2)],index=self.pnl_history.columns)
+            pnl = pd.Series(data=[round((self.total_value/self._capital-1)*100,2)],index=self.pnl_history.columns)
             pnl.name = dpoint
             self.pnl_history = self.pnl_history.append(pnl)
             p = pd.Series(data=[closing_price[point]],index=self.p_history.columns)
